import unittest

from skua.preprocessors import Config
from skua.preprocessors.markdown import MarkdownPreprocessor


class TestMarkdownPreprocessor(unittest.TestCase):
    def testFile1(self):
        config = Config({
            'site_name': "HELLO WORLD!",
            "author": "Person 1"
        })
        import os
        markdown_preprocessor = MarkdownPreprocessor(config)
        output = markdown_preprocessor('tests/src/index.md')

        self.assertTrue(output['site_name'] == config.config['site_name'])
        self.assertTrue(output['author'] == config.config['author'])
        self.assertTrue(output['content'] is not None)



import frontmatter
import markdown

from . import Preprocessor, Config


class MarkdownPreprocessor(Preprocessor):
    def __init__(self, config: Config):
        super(MarkdownPreprocessor, self).__init__(config)

    def preprocess(self, input_file):
        file = frontmatter.load(input_file)
        content = markdown.markdown(file.content)
        file = dict(file)
        file['content'] = content
        return file



class Config(object):
    def __init__(self, config: dict):
        self.config: dict = config

    def __call__(self, file_dict) -> dict:
        # config keys overwrite the keys specified in the file
        return {**file_dict, **self.config}


class Preprocessor(object):
    def __init__(self, config: Config):
        self.config = config

    def preprocess(self, *args, **kwargs) -> dict:
        pass

    def __call__(self, input_file) -> dict:
        return self.config(self.preprocess(input_file))



import unittest

from skua.preprocessors import Config
from skua.preprocessors.markdown import MarkdownPreprocessor
from skua.render import Templates


class TestRenderWithMockSite(unittest.TestCase):
    def setUp(self):
        self.templates = Templates(__name__, 'tests/src/templates')
        self.config = Config({
            'site_name': "Test Site!",
            'author': "Person 1"
        })
        self.md_preprocessor = MarkdownPreprocessor(self.config)

    def loadAndRenderMarkdown(self, file):
        print(self.md_preprocessor(file))
        return self.templates.render_template(**self.md_preprocessor(file))

    def testFile1(self):
        rendered_file = self.loadAndRenderMarkdown('tests/src/blog/skua-is-a-static-site-generator.md')
        print(rendered_file)



import glob
import os
import re
from typing import Dict

import jinja2


class Templates(object):
    def __init__(self, import_name, template_dir: str, template_extension: str = 'html',
                 template_prefix: str = "skua_"):
        """
        Stores jinja2 templates. Please note that templates need to be unique.
        :param import_name: Usually `__name__` (a builtin variable)
        :param template_dir: The folder in which the templates can be found.
        :param template_extension: All files without this extension are ignored.
        """
        if not os.path.isdir(template_dir):
            raise LookupError("The template folder cannot be found.")
        self.env = jinja2.Environment(
            loader=jinja2.FileSystemLoader(template_dir)
        )
        template_dir_index = [template for template in
                              glob.glob(os.path.join(os.path.abspath(template_dir), '**'), recursive=True) if
                              re.search(template_prefix, template) and os.path.splitext(os.path.split(template)[1])[
                                  1] == '.' + template_extension]

        self.templates: Dict = dict(
            [(os.path.splitext(os.path.split(str(template_file))[1])[0],
              self.env.get_template(os.path.relpath(template_file, template_dir))) for
             template_file in template_dir_index])

    def render_template(self, template, **kwargs):
        return self.templates[template].render(**kwargs)
